package com.gct.dlview.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.gct.common.core.result.Result;
import com.gct.dlview.entity.DeepLearnTrainServer;
import com.gct.dlview.entity.vo.PageBody;
import com.gct.dlview.mapper.DeepLearnTrainServerMapper;
import com.gct.dlview.service.DeepLearnTrainServerService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author lloyd
 * @since 2021-08-15
 */
@Service
public class DeepLearnTrainServerServiceImpl extends ServiceImpl<DeepLearnTrainServerMapper, DeepLearnTrainServer> implements DeepLearnTrainServerService {

    @Autowired
    DeepLearnTrainServerMapper mapper;

    @Override
    public Result getPageByCondition(PageBody<DeepLearnTrainServer> pageBody) {
        if (Objects.isNull(pageBody) || Objects.isNull(pageBody.getPage()) || Objects.isNull(pageBody.getCondition()))
            return Result.error("输入参数错误");
        Page<DeepLearnTrainServer> data = mapper.getTrainServerByCondition(pageBody.getPage(), pageBody.getCondition());
        if (Objects.isNull(data) || data.getRecords().isEmpty()) return Result.error("无数据");
        else return Result.ok(data);
    }

    @Override
    public Result getOneByCondition(DeepLearnTrainServer condition) {
        if (Objects.isNull(condition))
            return Result.error("输入参数错误");
        List<DeepLearnTrainServer> data = mapper.getTrainServerByCondition(condition);
        if (Objects.isNull(data) || data.isEmpty()) return Result.error("无数据");
        return Result.ok(data.get(0));
    }

    @Override
    public Result deleteOneById(DeepLearnTrainServer condition) {
        if (Objects.isNull(condition) || Objects.isNull(condition.getId()))
            return Result.error("输入参数错误");
        int i = mapper.deleteById(condition.getId());
        if (i <= 0) return Result.error("删除失败");
        return Result.ok("删除成功");
    }

    @Override
    public Result deleteBatchById(List<DeepLearnTrainServer> condition) {
        if (Objects.isNull(condition) || condition.isEmpty())
            return Result.error("输入参数错误");
        List<Serializable> ids = new ArrayList<>();
        condition.forEach(item -> {
            if (Objects.nonNull(item) && item.getId() != null)
                ids.add(item.getId());
        });
        int i = mapper.deleteBatchIds(ids);
        if (i <= 0) return Result.error("删除失败");
        return Result.ok("删除成功");
    }

    @Override
    public Result saveOne(DeepLearnTrainServer deepLearnTrainServer) {
        if (Objects.isNull(deepLearnTrainServer))
            return Result.error("没有输入数据");
        if (Objects.isNull(deepLearnTrainServer.getId()) || deepLearnTrainServer.getId() <= 0)
            deepLearnTrainServer.setId(null);
        if (Objects.isNull(deepLearnTrainServer.getMachineId()) || deepLearnTrainServer.getMachineId() <= 0)
            return Result.error("没有选择正确设备");
        if(Objects.isNull(deepLearnTrainServer.getServerName())||deepLearnTrainServer.getServerName().isEmpty())
            return Result.error("输入正确的服务名称");
        if (Objects.isNull(deepLearnTrainServer.getCreateTime()))
            deepLearnTrainServer.setCreateTime(LocalDateTime.now());
        deepLearnTrainServer.setUpdateTime(LocalDateTime.now());
        try {
            boolean sus = this.save(deepLearnTrainServer);
            if (sus) return Result.ok("保存成功");
            return Result.error("保存失败");
        } catch (Exception e) {
            return Result.error("save failed:" + e.getMessage());
        }
    }
}
